==> nukleus-0.0.5.gem: spec/models/nukleus/document_spec.rb <==
require 'rails_helper'
require "refile/file_double"

module Nukleus
    RSpec.describe Document, type: :model do
        before(:example) do
            NoBrainer.purge!
            NoBrainer.sync_indexes
        end

        let(:doc) { Document.new({:document_id =>"test_doc_id", :tags => ["a","b"], :meta_data => { test: "me" }}) }

        it "can be created" do
            # Create a simple document
            expect(doc).not_to eq(nil)
            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")

            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }
        end

        it "can be changed" do
            expect(doc).not_to eq(nil)
            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")
            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }

            # Do some change and save
            expect {
                doc.tags = ["g","k"]
                expect(doc.save).to eq(true)
            }.not_to change { Document.count }
        end

        it "can be updated with versioning" do
            # Check versionioning
            expect {
                doc.update_with_copy(:tags => ["s","k"])
            }.to change { Document.count }

            expect {
                expect(doc.update_with_copy(:tags => ["s","k"])).not_to eq(nil)
                expect(Document.where(document_id: doc.document_id).count).to eq(2)
                Document.where(document_id: doc.document_id).first.destroy
                expect(Document.where(document_id: doc.document_id).count).to eq(0)
            }.to change { Document.count }

        end

        it "can be removed" do
            expect(doc).not_to eq(nil)

            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")
            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }

            expect {
                expect(doc.destroy).to eq(true)
            }.to change { Document.count }
        end
    end
end

==> nukleus-0.1.0.gem: spec/models/nukleus/document_spec.rb <==
require 'rails_helper'
require "refile/file_double"

module Nukleus
    RSpec.describe Document, type: :model do
        before(:example) do
            NoBrainer.purge!
            NoBrainer.sync_indexes
        end

        let(:doc) { Document.new({:document_id =>"test_doc_id", :tags => ["a","b"], :meta_data => { test: "me" }}) }

        it "can be created" do
            # Create a simple document
            expect(doc).not_to eq(nil)
            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")

            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }
        end

        it "can be changed" do
            expect(doc).not_to eq(nil)
            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")
            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }

            # Do some change and save
            expect {
                doc.tags = ["g","k"]
                expect(doc.save).to eq(true)
            }.not_to change { Document.count }
        end

        it "can be updated with versioning" do
            # Check versionioning
            expect {
                doc.update_with_copy(:tags => ["s","k"])
            }.to change { Document.count }

            expect {
                expect(doc.update_with_copy(:tags => ["s","k"])).not_to eq(nil)
                expect(Document.where(document_id: doc.document_id, all_document_versions:true).count).to eq(2)
                Document.where(document_id: doc.document_id).first.destroy
                expect(Document.where(document_id: doc.document_id).count).to eq(0)
            }.to change { Document.count }

        end

        it "can be removed" do
            expect(doc).not_to eq(nil)

            doc.document_file = Refile::FileDouble.new("dummy", "logo.png", content_type: "image/png")
            expect {
                expect(doc.save).to eq(true)
            }.to change { Document.count }

            expect {
                expect(doc.destroy).to eq(true)
            }.to change { Document.count }
        end
    end
end
